@@ -1,4 +1,4 @@
-/*  $Id: innd.h 9263 2011-07-17 18:27:22Z iulius $
+/*  $Id: innd.h 10263 2018-03-10 14:51:53Z iulius $
 **
 **  Many of the data types used here have abbreviations, such as CT for a
 **  channel type.  Here are a list of the conventions and meanings:
@@ -28,7 +28,7 @@
 #define INND_H 1
 
 #include "config.h"
-#include "portable/time.h"
+#include "portable/macros.h"
 #include "portable/socket.h"
 #include <ctype.h>
 #include <errno.h>
@@ -37,6 +37,11 @@
 #include <syslog.h> 
 #include <sys/stat.h>
 
+#ifdef HAVE_SYS_TIME_H
+# include <sys/time.h>
+#endif
+#include <time.h>
+
 #include "inn/buffer.h"
 #include "inn/history.h"
 #include "inn/messages.h"
@@ -45,6 +50,7 @@
 #include "inn/nntp.h"
 #include "inn/paths.h"
 #include "inn/storage.h"
+#include "inn/vector.h"
 
 BEGIN_DECLS
 
@@ -214,8 +220,9 @@ typedef struct _HDRCONTENT {
 #define HDR__ARCHIVED_AT        72
 #define HDR__SUMMARY            73
 #define HDR__COMMENTS           74
+#define HDR__JABBER_ID          75
 
-#define MAX_ARTHEADER           75
+#define MAX_ARTHEADER           76
 
 /*
 **  Miscellaneous data we want to keep on an article.  All the fields
@@ -693,7 +700,8 @@ extern void		SetupListBuffer(int size, LISTBUFFER *list);
 extern char         *	MaxLength(const char *p, const char *q);
 extern pid_t		Spawn(int niceval, int fd0, int fd1, int fd2,
 			      char * const av[]);
-extern void		CleanupAndExit(int x, const char *why) __attribute__ ((noreturn));
+extern void		CleanupAndExit(int x, const char *why)
+    __attribute__ ((__noreturn__));
 extern void		JustCleanup(void);
 extern void		ThrottleIOError(const char *when);
 extern void		ThrottleNoMatchError(void);
@@ -723,7 +731,8 @@ extern CHANNEL      *	CHANfromdescriptor(int fd);
 extern char	    *   CHANname(CHANNEL *cp);
 extern int		CHANreadtext(CHANNEL *cp);
 extern void		CHANclose(CHANNEL *cp, const char *name);
-extern void		CHANreadloop(void) __attribute__ ((noreturn));
+extern void		CHANreadloop(void)
+    __attribute__ ((__noreturn__));
 extern void		CHANsetup(int i);
 extern void		CHANshutdown(void);
 extern void		CHANtracing(CHANNEL *cp, bool Flag);
